##  Activating the Inventory Builder
The inventory builder is not enabled by default and must be activated separately for eligible workspaces.
To activate the inventory builder:
  1. Go to Administration > Optional Features and Early Access.
  2. Choose Activate next to AI-Assisted Inventory Builder.


If AI units are not available, an information banner appears under AI Features in the Optional Features and Early Access section. To request activation of the inventory builder, submit a support ticket.
![Optional Features and Early Access page showing AI feature activation options.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa4c6944d8e584f47874d633ad544f3df_LowRes.png)
